/*
 * httpdmodule.c
 *
 * Curses based IP-Filter logs viewer
 *
 * Copyright (C) 2001  Pierre Berthomier
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation, provided that this notice
 * is preserved in its entirety and due credit is given to the original
 * author and the contributors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

/*
 * void     httpd_fields_to_fmt_and_attr_lines(logline * ll)
 * chtype * httpd_headers_line(chtype * chstr)
 */

#include "vlog.h"

void httpd_fields_to_fmt_and_attr_lines(
  logline * ll)
{

  char     buf[PADWIDTH + 1];
  char     fmtline[PADWIDTH + 1];
  char     attrline[PADWIDTH + 1];
  char *   cur_fmt_char;
  char *   cur_attr_char;
  int      mark_attr;

  mark_attr = (ll->is_marked ? MYA_REVERSE : MYA_NORMAL) | MY_BIT7;
  *fmtline  = '\0';
  *attrline = '\0';
  cur_fmt_char  = fmtline;
  cur_attr_char = attrline;

  if (*(ll->month)) {		// if this line was correctly recognised (has a date/time)
    if (option_show_date) {							// DATE
      sprintf(buf, "%3s %2d ", ll->month, ll->day);
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
    }

    if (option_show_time) {							// TIME
      sprintf(buf, "%02d:%02d:%02d ", ll->hour, ll->minute, ll->second);
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
    }

    if (ll->httpd_access_line) {
      if (option_show_httpd_client_ip) {					// HTTPD CLIENT IP ADDR
        sprintf(buf, "%*s ", HTTP_CLIENT_IP_NCOLS, (ll->client_addr ? ll->client_addr : ""));
        append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
      }

      if (option_show_httpd_client_user) {					// HTTPD CLIENT USER
        sprintf(buf, "%-*s ", HTTP_CLIENT_USER_NCOLS, (ll->client_user ? ll->client_user : ""));
        append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
      }

      if (option_show_httpd_code) {						// HTTP CODE
        sprintf(buf, " %03d ", ll->http_code);
        append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
      }

      if (option_show_httpd_length) {						// HTTP LENGTH
        sprintf(buf, "%6d ", ll->http_size);
        append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
      }
    }

    if (ll->message)
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, ll->message, mark_attr);

  } else	// syslog format not recognised. Display as raw.
    append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, ll->line, mark_attr);

  *cur_fmt_char  = '\0';			// terminate formatted (both chars and attr) strings
  *cur_attr_char = '\0';

  if (ll->fmtline && ll->fmtline != ll->line)
    tfree(ll->fmtline);
  if (ll->attrline)
    tfree(ll->attrline);

  ll->fmtline  = tstrdup(fmtline);
  ll->attrline = tstrdup(attrline);
}

chtype * httpd_headers_line(
  chtype * chstr)
{
  *chstr = (chtype) 0;

  if (option_show_date)
    strcat_to_chstr(chstr, A_REVERSE, "%-6s ", "Date");

  if (option_show_time)
    strcat_to_chstr(chstr, A_REVERSE, "%-8s ", "Time");

  if (mode_httpd_access && option_show_httpd_client_ip)
    strcat_to_chstr(chstr, A_REVERSE, "%*s ", HTTP_CLIENT_IP_NCOLS, "Source Address");

  if (mode_httpd_access && option_show_httpd_client_user)
    strcat_to_chstr(chstr, A_REVERSE, "%-*s ", HTTP_CLIENT_USER_NCOLS, "User");

  if (mode_httpd_access && option_show_httpd_code)
    strcat_to_chstr(chstr, A_REVERSE, "%4s ", "Code");

  if (mode_httpd_access && option_show_httpd_length)
    strcat_to_chstr(chstr, A_REVERSE, "%5s ", "Length");

  strcat_to_chstr(chstr,   A_REVERSE, "%s ", "Message");

  headers_append_host_logfilename(chstr);

  strcat_to_chstr(chstr, A_REVERSE, "%*s", PADWIDTH - chstrlen(chstr) - 1, "");

  return chstr;
}


