/*
 * Safer Memory Allocation
 * Copyright (C) 1997 Kaz Kylheku <kaz@cafe.net>
 *
 * Free Software License:
 *
 * All rights are reserved by the author, with the following exceptions:
 * Permission is granted to freely reproduce and distribute this software,
 * possibly in exchange for a fee, provided that this copyright notice appears
 * intact. Permission is also granted to adapt this software to produce
 * derivative works, as long as the modified versions carry this copyright
 * notice and additional notices stating that the work has been modified.
 * The copyright extends to translations of this work into other languages,
 * including machine languages. 
 *
 * $Id: smalloc.h,v 1.4 1997/08/23 14:42:45 kaz Exp $
 * $Name: release_1_4 $
 */

#ifndef SMALLOC_H
#define SMALLOC_H

#include <stddef.h>

/*
 * Blurb for inclusion into C++ translation units
 */

#ifdef __cplusplus
extern "C" {
#endif

typedef char safe_magic_t[7];

extern void *safe_malloc(size_t size, const safe_magic_t *magic);
extern void *safe_calloc(size_t nmemb, size_t size, const safe_magic_t *magic);
extern void safe_free(void *ptr, size_t size, const safe_magic_t *magic);
extern void *safe_realloc(void *oldptr, size_t oldsize,
	size_t newsize, const safe_magic_t *magic);

#ifdef NDEBUG
    #define safe_malloc(A, B)		malloc(A)
    #define safe_calloc(A, B, C)	calloc(A, B)
    #define safe_free(A, B, C)		free(A)
    #define safe_realloc(A, B, C, D)	realloc(A, C)
#endif

#ifdef __cplusplus
}
#endif

#endif
