/*
 * syslogmodule.c
 *
 * Curses based IP-Filter logs viewer
 *
 * Copyright (C) 2001  Pierre Berthomier
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation, provided that this notice
 * is preserved in its entirety and due credit is given to the original
 * author and the contributors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

/*
 * void     syslog_fields_to_fmt_and_attr_lines(logline * ll)
 * chtype * syslog_headers_line(chtype * chstr)
 */

#include "vlog.h"


void syslog_fields_to_fmt_and_attr_lines(
  logline * ll)
{
  char     buf[PADWIDTH + 1];
  char     fmtline[PADWIDTH + 1];
  char     attrline[PADWIDTH + 1];
  char *   cur_fmt_char;
  char *   cur_attr_char;
  int      mark_attr;

  mark_attr = (ll->is_marked ? MYA_REVERSE : MYA_NORMAL) | MY_BIT7;
  *fmtline  = '\0';
  *attrline = '\0';
  cur_fmt_char  = fmtline;
  cur_attr_char = attrline;

  if (*(ll->month)) {		// if this line is a standard syslog one (has a date/time/hostname)
    if (option_show_date) {						// DATE
      sprintf(buf, "%3s %2d ", ll->month, ll->day);
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
    }

    if (option_show_time) {						// TIME
      sprintf(buf, "%02d:%02d:%02d ", ll->hour, ll->minute, ll->second);
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
    }

    if (option_show_hostname) {						// HOSTNAME
      sprintf(buf, "%-*.*s ", nchars_host, nchars_host, ll->host);
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
    }

    if (option_show_proc_name) {
      sprintf(buf, "%-*s ", proc_name_width, (ll->fields ? (char *) ll->fields : ""));
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
    }

    if (option_show_pid) {
      if (ll->pid)
        sprintf(buf, "%5d ", ll->pid);
      else
        sprintf(buf, "%5s ", "");
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, buf, mark_attr);
    }

    if (ll->message)
      append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, ll->message, mark_attr);

  } else	// syslog format not recognised. Display as raw.
    append_to_fmt_and_attr_strings(cur_fmt_char, cur_attr_char, ll->line, mark_attr);

  *cur_fmt_char  = '\0';			// terminate formatted (both chars and attr) strings
  *cur_attr_char = '\0';

  if (ll->fmtline && ll->fmtline != ll->line)
    tfree(ll->fmtline);
  if (ll->attrline)
    tfree(ll->attrline);

  ll->fmtline  = tstrdup(fmtline);
  ll->attrline = tstrdup(attrline);
}


chtype * syslog_headers_line(
  chtype * chstr)
{
  *chstr = (chtype) 0;

  if (option_show_date)
    strcat_to_chstr(chstr, A_REVERSE, "%-6s ", "Date");

  if (option_show_time)
    strcat_to_chstr(chstr, A_REVERSE, "%-8s ", "Time");

  if (option_show_hostname)
    strcat_to_chstr(chstr, A_REVERSE, "%-*s ", nchars_host, "Hostname");

  if (option_show_proc_name)
    strcat_to_chstr(chstr, A_REVERSE, "%-*s ", proc_name_width, "Process");

  if (option_show_pid)
    strcat_to_chstr(chstr, A_REVERSE, "%-5s ", " Pid");

  strcat_to_chstr(chstr,   A_REVERSE, "%s ", "Message");

  headers_append_host_logfilename(chstr);

  strcat_to_chstr(chstr, A_REVERSE, "%*s", PADWIDTH - chstrlen(chstr) - 1, "");

  return chstr;
}


